==> zio-aws-apigateway_3-5.17.126.2-sources.jar: zio/aws/apigateway/model/UpdateRequestValidatorResponse.scala <==
package zio.aws.apigateway.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters.*
final case class UpdateRequestValidatorResponse(
    id: Option[String] = None,
    name: Option[String] = None,
    validateRequestBody: Option[Boolean] = None,
    validateRequestParameters: Option[Boolean] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.apigateway.model.UpdateRequestValidatorResponse = {
    import UpdateRequestValidatorResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.apigateway.model.UpdateRequestValidatorResponse
      .builder()
      .optionallyWith(id.map(value => value: java.lang.String))(_.id)
      .optionallyWith(name.map(value => value: java.lang.String))(_.name)
      .optionallyWith(
        validateRequestBody.map(value => value: java.lang.Boolean)
      )(_.validateRequestBody)
      .optionallyWith(
        validateRequestParameters.map(value => value: java.lang.Boolean)
      )(_.validateRequestParameters)
      .build()
  }
  def asReadOnly
      : zio.aws.apigateway.model.UpdateRequestValidatorResponse.ReadOnly =
    zio.aws.apigateway.model.UpdateRequestValidatorResponse
      .wrap(buildAwsValue())
}
object UpdateRequestValidatorResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.apigateway.model.UpdateRequestValidatorResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.apigateway.model.UpdateRequestValidatorResponse =
      zio.aws.apigateway.model.UpdateRequestValidatorResponse(
        id.map(value => value),
        name.map(value => value),
        validateRequestBody.map(value => value),
        validateRequestParameters.map(value => value)
      )
    def id: Option[String]
    def name: Option[String]
    def validateRequestBody: Option[Boolean]
    def validateRequestParameters: Option[Boolean]
    def getId: ZIO[Any, AwsError, String] = AwsError.unwrapOptionField("id", id)
    def getName: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("name", name)
    def getValidateRequestBody: ZIO[Any, AwsError, Boolean] =
      AwsError.unwrapOptionField("validateRequestBody", validateRequestBody)
    def getValidateRequestParameters: ZIO[Any, AwsError, Boolean] = AwsError
      .unwrapOptionField("validateRequestParameters", validateRequestParameters)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.apigateway.model.UpdateRequestValidatorResponse
  ) extends zio.aws.apigateway.model.UpdateRequestValidatorResponse.ReadOnly {
    override val id: Option[String] =
      scala.Option(impl.id()).map(value => value: String)
    override val name: Option[String] =
      scala.Option(impl.name()).map(value => value: String)
    override val validateRequestBody: Option[Boolean] =
      scala.Option(impl.validateRequestBody()).map(value => value: Boolean)
    override val validateRequestParameters: Option[Boolean] = scala
      .Option(impl.validateRequestParameters())
      .map(value => value: Boolean)
  }
  def wrap(
      impl: software.amazon.awssdk.services.apigateway.model.UpdateRequestValidatorResponse
  ): zio.aws.apigateway.model.UpdateRequestValidatorResponse.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-apigateway_3-5.17.295.3-sources.jar: zio/aws/apigateway/model/UpdateRequestValidatorResponse.scala <==
package zio.aws.apigateway.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters.*
final case class UpdateRequestValidatorResponse(
    id: Optional[String] = Optional.Absent,
    name: Optional[String] = Optional.Absent,
    validateRequestBody: Optional[Boolean] = Optional.Absent,
    validateRequestParameters: Optional[Boolean] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.apigateway.model.UpdateRequestValidatorResponse = {
    import UpdateRequestValidatorResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.apigateway.model.UpdateRequestValidatorResponse
      .builder()
      .optionallyWith(id.map(value => value: java.lang.String))(_.id)
      .optionallyWith(name.map(value => value: java.lang.String))(_.name)
      .optionallyWith(
        validateRequestBody.map(value => value: java.lang.Boolean)
      )(_.validateRequestBody)
      .optionallyWith(
        validateRequestParameters.map(value => value: java.lang.Boolean)
      )(_.validateRequestParameters)
      .build()
  }
  def asReadOnly
      : zio.aws.apigateway.model.UpdateRequestValidatorResponse.ReadOnly =
    zio.aws.apigateway.model.UpdateRequestValidatorResponse
      .wrap(buildAwsValue())
}
object UpdateRequestValidatorResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.apigateway.model.UpdateRequestValidatorResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.apigateway.model.UpdateRequestValidatorResponse =
      zio.aws.apigateway.model.UpdateRequestValidatorResponse(
        id.map(value => value),
        name.map(value => value),
        validateRequestBody.map(value => value),
        validateRequestParameters.map(value => value)
      )
    def id: Optional[String]
    def name: Optional[String]
    def validateRequestBody: Optional[Boolean]
    def validateRequestParameters: Optional[Boolean]
    def getId: ZIO[Any, AwsError, String] = AwsError.unwrapOptionField("id", id)
    def getName: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("name", name)
    def getValidateRequestBody: ZIO[Any, AwsError, Boolean] =
      AwsError.unwrapOptionField("validateRequestBody", validateRequestBody)
    def getValidateRequestParameters: ZIO[Any, AwsError, Boolean] = AwsError
      .unwrapOptionField("validateRequestParameters", validateRequestParameters)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.apigateway.model.UpdateRequestValidatorResponse
  ) extends zio.aws.apigateway.model.UpdateRequestValidatorResponse.ReadOnly {
    override val id: Optional[String] = zio.aws.core.internal
      .optionalFromNullable(impl.id())
      .map(value => value: String)
    override val name: Optional[String] = zio.aws.core.internal
      .optionalFromNullable(impl.name())
      .map(value => value: String)
    override val validateRequestBody: Optional[Boolean] = zio.aws.core.internal
      .optionalFromNullable(impl.validateRequestBody())
      .map(value => value: Boolean)
    override val validateRequestParameters: Optional[Boolean] =
      zio.aws.core.internal
        .optionalFromNullable(impl.validateRequestParameters())
        .map(value => value: Boolean)
  }
  def wrap(
      impl: software.amazon.awssdk.services.apigateway.model.UpdateRequestValidatorResponse
  ): zio.aws.apigateway.model.UpdateRequestValidatorResponse.ReadOnly =
    new Wrapper(impl)
}
